# Windows Setup

* Make a system restore point after a fresh install

* Change PC name and reboot

* Disable `Enhance Pointer Precision`:
    * Mouse Properties -> Pointer Options -> Motion section

* Laptop: change touchpad sensitivity to medium or high in order to prevent mouse movement when palm touches the pad while typing.
    * If using a Lenovo then disable touchpad lock in the Lenovo Vantage app.

* Map caps key to left-ctrl using Sharpkeys.

* Download [O&O ShutUp10](https://www.oo-software.com/en/shutup10) and disable things.

* Install Open-Shell to restore the start menu to the sensible Windows 7 style.

* Pin "This PC" to taskbar
    * In Win 10 start menu, search for "This PC", right click top result and pin to taskbar

* Configure Explorer's options
    * Open file explorer, click on File menu then options or "Change folder and search options"
        * General tab
            * `Open File Explorer to: This PC`
            * Uncheck `Show recently used files in Quick access`
            * Uncheck `Show frequently used folder in Quick access`
        * View tab
            * Check `Show hidden files, folders, or drives`,
            * Uncheck `Hide extensions for known file types`

* Disable reopening apps on startup
    * Windows settings -> Account -> Sign in options -> Privacy section: turn off `Use my sign-in info to automatically finish setting up device`

* Disable window suggestion when snapping a window
    * Windows settings -> System -> Multitasking -> uncheck "When I snap a window, show what I can snap next to it"

* Desktop: turn off hibernation
    * Open admin cmd prompt: `powercfg.exe /hibernate off`

* Disable power throttling:
    * winkey+r -> `gpedit.msc`.
    * Computer Configuration > Administrative Templates > System > Power Management > Power Throttling Settings
        * Double-click the `Turn off Power Throttling` policy.
        * Select Enabled.

* Disable reserved network bandwidth
    * winkey+r -> `gpedit.msc`.
    * Computer Configuration > Administrative Templates > Network > QoS Packet Scheduler > Limit reservable bandwidth
        * Enable it and set the % to 0.

* Enable ultimate power plan (alternatively make a new plan and set the min/max processor speed to 100%)
    * Open cmd as admin, run `powercfg -duplicatescheme e9a42b02-d5df-448d-aa00-03f14749eb61`
    * Can now select the ultimate power plan in power options.

* Create a power plan for software benchmarking
    * This will disable turbo boost and general lock the frequency to base-ish clock. This can help
    keep CPU temps stable (hot temps affect clock) and it avoids variable clock changes.
    * AFAIK this only works for Intel CPUs; not sure how to do the same thing on AMD.
    * In the power plan set the processor min/max speed to 99%.

* Disable UAC screen dimming
    * Open User Account Control settings
    * Drag the slider down one notch to remove the dimming

* Disable Windows error reporting dialog so that when stuff crashes you can get to a debugger faster.
    * Open an admin cmd prompt and run the file `disable-windows-error-reporting-dialog.bat` from this directory.

* Disable the WinSAT task which is used to figure out your Windows performance score. It eats up
processor time and is generally useless.
    * Open task scheduler.
        * **note** If you see an error about a selected task {0} no longer existing then you'll need
          to repair the task scheduler. See
          https://www.thewindowsclub.com/the-selected-task-0-no-longer-exists-error-in-task-scheduler
    * Go to `Local` -> `Microsoft` -> `Maintenance` and disable the WinSAT task.

* Disable the Windows Customer Experience Improvement program via group policy
  https://web.archive.org/web/20200131202352/https://www.ghacks.net/2016/10/26/turn-off-the-windows-customer-experience-program/

* Increase TDR setting for GPU Driver
    * TDR determines the length of time that a GPU can hang on a computation until the OS restarts
      the driver. By default this is set to a few seconds so you can experience app crashes when
      using GPU intensive software, like 3D modeling or texturing. To increase the duration, follow
      this guide: https://web.archive.org/web/20191107173337/https://docs.substance3d.com/spdoc/gpu-drivers-crash-with-long-computations-128745489.html

* **Optional:** disable Windows Defender real-time protection:
    * This can speed up compilation times since Defender will scan every file written to disk. I was
      able to shave off ~2-5 seconds in a particular project.
        * If you'd rather keep real-time protection active then you can add specific files or
          folders to the Defender exclusion list in the Windows Security settings, however I did
          some testing and didn't see any speedup when excluding a project folder.
    * Go into the Windows security settings and disable `Tamper Protection`.
        * winkey+r -> `gpedit.msc`.
        * Computer Configuration > Administrative Templates > Windows Components > Microsoft Defender Antivirus -> Real-time Protection
            * Double-click the `Turn off real-time protection` policy.
            * Select Enabled (you may have to restart PC).
            * If you want to re-enable then change the policy to `Not configured` and re-enable tamper protection.

* Enable/disable various Window features:
    * Go to Add/Remove Programs -> Turn Windows features on or off
    * Enable:
        * Windows hypervisor platform
    * Disable:
        * Internet Explorer 11
        * Legacy Components - DirectPlay
        * Media Features - Windows Media Player
        * Microsoft Print to PDF
        * Microsoft XPS Document Writer (and any other XPS components)
        * Print and Document Services - Internet Printing Client & Windows Fax and Scan
        * Windows PowerShell 2.0 (current version is 5+ as of 2021-03-05)
        * Work folders client

* Restore classic Windows Photo Viewer app (the default Win10 photos app is fucking awful):
    * Run photo_viewer.reg from this folder.
    * You'll need to change the default app for the various image extensions. Don't change gif types
      though because photo viewer doesn't support animations.
    * Now run disable-are-you-sure-you-want-to-open-with-the-default-program-dialog.reg to stop it
      from occasionally asking if you still want to use photo viewer.

* Add custom hosts file
    * Run notepad as administrator
    * Open C:/Windows/System32/Drivers/etc/hosts
    * Add contents of the hosts file from this directory
    * Restart PC
    * Note: Windows Defender is going to alert you about the change. Tell it to ignore. Also, POS Windows will periodically reset this file to the default state so you'll want to check it every so often.

* Install the Windows SDK https://developer.microsoft.com/en-us/windows/downloads/windows-10-sdk
    * Will install to c:\Program Files (x86)\Windows Kits\10

* Setup a symbol server:
    * Right-click My Computer -> Properties -> Advanced Tab -> Environment Variables
    * Add a new System Variable called `_NT_SYMBOL_PATH`
    * Set the value to `SRV*c:\symbols*http://msdl.microsoft.com/download/symbols`, replacing the
      first path to where you want the symbols to live.

* Configure crash dump storage location for projects via the registry.

* Disable various web trackers using browserleaks.com as a guide.
    * e.g. disable WebGL, canvas fingerprinting, geolocation, font fingerprint, etc.

* Turn off various startup processes
    * ctrl+shift+esc -> startup

* Disable unneeded services

* Do a pass over all Windows setting screens for anything obvious that wasn't covered here.
